Documentation
¶
Overview ¶
Package encoding contains Content-Encoding related filters.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Gzip ¶
Gzip calls the next handler with a response writer that will compress the outbound writes with the default compression level. This filter assumes a chunked transfer encoding, so do not add a Content-Length header in the terminal handler.
If the request does not accept a gzip encoding, this filter has no effect.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.